@@ -2,10 +2,10 @@
 # -*- coding: utf-8 -*-
 
 import argparse
-import logging
 import os
 import sys
 
+from rich.panel import Panel
 from vdb.lib import config as config
 from vdb.lib import db as dbLib
 from vdb.lib.gha import GitHubSource
@@ -15,19 +15,16 @@ from depscan.lib import utils as utils
 from depscan.lib.analysis import (
     analyse,
     analyse_licenses,
+    analyse_pkg_risks,
     jsonl_report,
     print_results,
     suggest_version,
 )
-from depscan.lib.audit import audit, type_audit_map
-from depscan.lib.bom import create_bom, get_pkg_list
+from depscan.lib.audit import audit, risk_audit, risk_audit_map, type_audit_map
+from depscan.lib.bom import create_bom, get_pkg_by_type, get_pkg_list
 from depscan.lib.config import license_data_dir
 from depscan.lib.license import build_license_data, bulk_lookup
-
-logging.basicConfig(
-    level=logging.INFO, format="%(levelname)s [%(asctime)s] %(message)s"
-)
-LOG = logging.getLogger(__name__)
+from depscan.lib.logger import LOG, console
 
 at_logo = """
   ___            _____ _                    _
@@ -76,6 +73,19 @@ def build_args():
         dest="suggest",
         help="Suggest appropriate fix version for each identified vulnerability.",
     )
+    parser.add_argument(
+        "--risk-audit",
+        action="store_true",
+        default=True if os.getenv("ENABLE_OSS_RISK", "") in ["true", "1"] else False,
+        dest="risk_audit",
+        help="Perform package risk audit (slow operation). Npm only.",
+    )
+    parser.add_argument(
+        "--private-ns",
+        dest="private_ns",
+        default=os.getenv("PKG_PRIVATE_NAMESPACE"),
+        help="Private namespace to use while performing oss risk audit. Private packages should not be available in public registries by default. Comma separated values accepted.",
+    )
     parser.add_argument(
         "-t",
         "--type",
@@ -85,10 +95,10 @@ def build_args():
     parser.add_argument(
         "--bom",
         dest="bom",
-        help="UNUSED: Examine using the given Software Bill-of-Materials (SBoM) file in CycloneDX format. Use cdxgen command to produce one.",
+        help="Examine using the given Software Bill-of-Materials (SBoM) file in CycloneDX format. Use cdxgen command to produce one.",
     )
     parser.add_argument(
-        "-i", "--src", dest="src_dir", help="Source directory", required=True
+        "-i", "--src", dest="src_dir_image", help="Source directory or container image"
     )
     parser.add_argument(
         "-o",
@@ -108,7 +118,7 @@ def build_args():
         action="store_true",
         default=False,
         dest="no_license_scan",
-        help="Do not perform a scan for license limitations",
+        help="DREPRECATED: dep-scan doesn't perform license scanning by default",
     )
     return parser.parse_args()
 
@@ -164,7 +174,7 @@ def scan(db, project_type, pkg_list, suggest_mode):
             LOG.debug(
                 "Re-checking our suggestion to ensure there are no further vulnerabilities"
             )
-            override_results, _ = utils.search_pkgs(db, sug_pkg_list)
+            override_results, _ = utils.search_pkgs(db, project_type, sug_pkg_list)
             if override_results:
                 new_sug_dict = suggest_version(override_results)
                 LOG.debug("Received override results: {}".format(new_sug_dict))
@@ -214,38 +224,58 @@ def summarise(
 def main():
     args = build_args()
     if not args.no_banner:
-        print(at_logo, flush=True)
-    # Set logging level
-    if os.environ.get("SCAN_DEBUG_MODE") == "debug":
-        LOG.setLevel(logging.DEBUG)
-    src_dir = args.src_dir
-    if not args.src_dir:
+        print(at_logo)
+    src_dir = args.src_dir_image
+    reports_base_dir = "."
+    if not src_dir:
         src_dir = os.getcwd()
-    db = dbLib.get()
-    run_cacher = args.cache
-    areport_file = (
-        args.report_file
-        if args.report_file
-        else os.path.join(src_dir, "reports", "depscan.json")
-    )
-    reports_dir = os.path.dirname(areport_file)
-    # Create reports directory
-    if not os.path.exists(reports_dir):
-        os.makedirs(reports_dir)
     # Detect the project types and perform the right type of scan
     if args.project_type:
         project_types_list = args.project_type.split(",")
     else:
         project_types_list = utils.detect_project_type(src_dir)
+    if "docker" in project_types_list:
+        reports_base_dir = os.getcwd()
+    db = dbLib.get()
+    run_cacher = args.cache
+    areport_file = (
+        args.report_file
+        if args.report_file
+        else os.path.join(reports_base_dir, "reports", "depscan.json")
+    )
+    reports_dir = os.path.dirname(areport_file)
+    # Create reports directory
+    if not os.path.exists(reports_dir):
+        os.makedirs(reports_dir)
     if len(project_types_list) > 1:
         LOG.debug("Multiple project types found: {}".format(project_types_list))
+    # Enable license scanning
+    if "license" in project_types_list:
+        os.environ["FETCH_LICENSE"] = "true"
+        project_types_list.remove("license")
+        console.print(
+            Panel(
+                f"License audit is enabled for this scan. This would increase the time by up to 10 minutes.",
+                title="License Audit",
+                expand=False,
+            )
+        )
     for project_type in project_types_list:
         sug_version_dict = {}
         pkg_aliases = {}
+        results = []
         report_file = areport_file.replace(".json", "-{}.json".format(project_type))
+        risk_report_file = areport_file.replace(
+            ".json", "-risk.{}.json".format(project_type)
+        )
         LOG.info("=" * 80)
-        bom_file = os.path.join(reports_dir, "bom-" + project_type + ".json")
-        creation_status = create_bom(project_type, bom_file, src_dir)
+        creation_status = False
+        if args.bom and os.path.exists(args.bom):
+            bom_file = args.bom
+            creation_status = True
+        else:
+            bom_file = os.path.join(reports_dir, "bom-" + project_type + ".json")
+            creation_status = create_bom(project_type, bom_file, src_dir)
         if not creation_status:
             LOG.debug("Bom file {} was not created successfully".format(bom_file))
             continue
@@ -254,8 +284,16 @@ def main():
         if not pkg_list:
             LOG.debug("No packages found in the project!")
             continue
-        scoped_pkgs = utils.get_pkgs_by_scope(pkg_list)
-        if not args.no_license_scan:
+        scoped_pkgs = {}
+        if project_type in ["python"]:
+            all_imports = utils.get_all_imports(src_dir)
+            LOG.debug(f"Identified {len(all_imports)} imports in your project")
+            scoped_pkgs = utils.get_scope_from_imports(
+                project_type, pkg_list, all_imports
+            )
+        else:
+            scoped_pkgs = utils.get_pkgs_by_scope(project_type, pkg_list)
+        if os.getenv("FETCH_LICENSE", "") in (True, "1", "true"):
             licenses_results = bulk_lookup(
                 build_license_data(license_data_dir), pkg_list=pkg_list
             )
@@ -263,6 +301,42 @@ def main():
                 reports_dir, "license-" + project_type + ".json"
             )
             analyse_licenses(project_type, licenses_results, license_report_file)
+        if project_type in risk_audit_map.keys():
+            if args.risk_audit:
+                console.print(
+                    Panel(
+                        f"Performing OSS Risk Audit for packages from {src_dir}\nNo of packages [bold]{len(pkg_list)}[/bold]. This will take a while ...",
+                        title="OSS Risk Audit",
+                        expand=False,
+                    )
+                )
+                try:
+                    risk_results = risk_audit(
+                        project_type,
+                        scoped_pkgs,
+                        args.private_ns,
+                        pkg_list,
+                        risk_report_file,
+                    )
+                    analyse_pkg_risks(
+                        project_type,
+                        scoped_pkgs,
+                        args.private_ns,
+                        risk_results,
+                        risk_report_file,
+                    )
+                except Exception as e:
+                    LOG.error(e)
+                    LOG.error("Risk audit was not successful")
+                    risk_results = None
+            else:
+                console.print(
+                    Panel(
+                        "Depscan supports OSS Risk audit for this project.\nTo enable set the environment variable [bold]ENABLE_OSS_RISK=true[/bold]",
+                        title="New Feature",
+                        expand=False,
+                    )
+                )
         if project_type in type_audit_map.keys():
             LOG.info(
                 "Performing remote audit for {} of type {}".format(
@@ -271,46 +345,65 @@ def main():
             )
             LOG.debug(f"No of packages {len(pkg_list)}")
             try:
-                results = audit(project_type, pkg_list, report_file)
+                audit_results = audit(project_type, pkg_list, report_file)
+                if audit_results:
+                    LOG.debug(f"Remote audit yielded {len(audit_results)} results")
+                    results = results + audit_results
             except Exception as e:
                 LOG.error("Remote audit was not successful")
                 LOG.error(e)
                 results = None
+        # In case of docker, check if there are any npm packages that can be audited remotely
+        if project_type in ("docker"):
+            npm_pkg_list = get_pkg_by_type(pkg_list, "npm")
+            if npm_pkg_list:
+                LOG.debug(f"No of packages {len(npm_pkg_list)}")
+                try:
+                    audit_results = audit("nodejs", npm_pkg_list, report_file)
+                    if audit_results:
+                        LOG.debug(f"Remote audit yielded {len(audit_results)} results")
+                        results = results + audit_results
+                except Exception as e:
+                    LOG.error("Remote audit was not successful")
+                    LOG.error(e)
+        if not dbLib.index_count(db["index_file"]):
+            run_cacher = True
         else:
-            if not dbLib.index_count(db["index_file"]):
-                run_cacher = True
-            else:
-                LOG.debug(
-                    "Vulnerability database loaded from {}".format(config.vdb_bin_file)
-                )
-            sources_list = [NvdSource()]
-            if os.environ.get("GITHUB_TOKEN"):
-                sources_list.insert(0, GitHubSource())
-            else:
-                LOG.info(
-                    "To use GitHub advisory source please set the environment variable GITHUB_TOKEN!"
-                )
-            if run_cacher:
-                for s in sources_list:
-                    LOG.debug("Refreshing {}".format(s.__class__.__name__))
-                    s.refresh()
-            elif args.sync:
-                for s in sources_list:
-                    LOG.debug("Syncing {}".format(s.__class__.__name__))
-                    s.download_recent()
             LOG.debug(
-                "Vulnerability database contains {} records".format(
-                    dbLib.index_count(db["index_file"])
-                )
+                "Vulnerability database loaded from {}".format(config.vdb_bin_file)
             )
+        sources_list = [NvdSource()]
+        if os.environ.get("GITHUB_TOKEN"):
+            sources_list.insert(0, GitHubSource())
+        else:
             LOG.info(
-                "Performing regular scan for {} using plugin {}".format(
-                    src_dir, project_type
-                )
+                "To use GitHub advisory source please set the environment variable GITHUB_TOKEN!"
             )
-            results, pkg_aliases, sug_version_dict = scan(
-                db, project_type, pkg_list, args.suggest
+        if run_cacher:
+            for s in sources_list:
+                LOG.debug("Refreshing {}".format(s.__class__.__name__))
+                s.refresh()
+                run_cacher = False
+        elif args.sync:
+            for s in sources_list:
+                LOG.debug("Syncing {}".format(s.__class__.__name__))
+                s.download_recent()
+                run_cacher = False
+        LOG.debug(
+            "Vulnerability database contains {} records".format(
+                dbLib.index_count(db["index_file"])
             )
+        )
+        LOG.info(
+            "Performing regular scan for {} using plugin {}".format(
+                src_dir, project_type
+            )
+        )
+        vdb_results, pkg_aliases, sug_version_dict = scan(
+            db, project_type, pkg_list, args.suggest
+        )
+        if vdb_results:
+            results = results + vdb_results
         # Summarise and print results
         summary = summarise(
             project_type,
