@@ -1,36 +1,15 @@
 # -*- coding: utf-8 -*-
 
 import json
-import logging
 
 from rich import box
-from rich.console import Console
-from rich.logging import RichHandler
-from rich.markdown import Markdown
 from rich.panel import Panel
 from rich.table import Table
-from rich.theme import Theme
 
+from depscan.lib import config as config
+from depscan.lib.logger import LOG, console
 from depscan.lib.utils import max_version
 
-custom_theme = Theme({"info": "cyan", "warning": "purple4", "danger": "bold red"})
-console = Console(
-    log_time=False,
-    log_path=False,
-    theme=custom_theme,
-    width=200,
-    color_system="256",
-    force_terminal=True,
-)
-
-logging.basicConfig(
-    level=logging.INFO,
-    format="%(message)s",
-    datefmt="[%X]",
-    handlers=[RichHandler(console=console, show_path=False, enable_link_path=False)],
-)
-LOG = logging.getLogger(__name__)
-
 
 def print_results(project_type, results, pkg_aliases, sug_version_dict, scoped_pkgs):
     """Pretty print report summary"""
@@ -70,6 +49,9 @@ def print_results(project_type, results, pkg_aliases, sug_version_dict, scoped_p
         id = vuln_occ_dict.get("id")
         package_issue = res.package_issue
         full_pkg = package_issue.affected_location.package
+        project_type_pkg = "{}:{}".format(
+            project_type, package_issue.affected_location.package
+        )
         if package_issue.affected_location.vendor:
             full_pkg = "{}:{}".format(
                 package_issue.affected_location.vendor,
@@ -82,15 +64,18 @@ def print_results(project_type, results, pkg_aliases, sug_version_dict, scoped_p
         package_name_style = ""
         id_style = ""
         pkg_severity = vuln_occ_dict.get("severity")
-        if full_pkg in required_pkgs and pkg_severity in ("CRITICAL", "HIGH"):
+        is_required = False
+        if full_pkg in required_pkgs or project_type_pkg in required_pkgs:
+            is_required = True
+        if is_required and pkg_severity in ("CRITICAL", "HIGH"):
             id_style = ":point_right: "
             pkg_attention_count = pkg_attention_count + 1
             if fixed_location:
                 fix_version_count = fix_version_count + 1
-        if full_pkg in required_pkgs:
+        if is_required:
             package_usage = "[bright_green][bold]Yes"
             package_name_style = "[bold]"
-        elif full_pkg in optional_pkgs:
+        elif full_pkg in optional_pkgs or project_type_pkg in optional_pkgs:
             package_usage = "[magenta]No"
             package_name_style = "[italic]"
         package = full_pkg.split(":")[-1]
@@ -176,15 +161,18 @@ def jsonl_report(
                 )
             # De-alias package names
             full_pkg = pkg_aliases.get(full_pkg, full_pkg)
+            project_type_pkg = "{}:{}".format(
+                project_type, package_issue.affected_location.package
+            )
             fixed_location = sug_version_dict.get(
                 full_pkg, package_issue.fixed_location
             )
             package_usage = "N/A"
-            if full_pkg in required_pkgs:
+            if full_pkg in required_pkgs or project_type_pkg in required_pkgs:
                 package_usage = "required"
-            elif full_pkg in optional_pkgs:
+            elif full_pkg in optional_pkgs or project_type_pkg in optional_pkgs:
                 package_usage = "optional"
-            elif full_pkg in excluded_pkgs:
+            elif full_pkg in excluded_pkgs or project_type_pkg in excluded_pkgs:
                 package_usage = "excluded"
             data_obj = {
                 "id": id,
@@ -202,6 +190,92 @@ def jsonl_report(
             outfile.write("\n")
 
 
+def analyse_pkg_risks(
+    project_type, scoped_pkgs, private_ns, risk_results, risk_report_file=None
+):
+    if not risk_results:
+        return
+    table = Table(
+        title=f"Risk Audit Summary ({project_type})",
+        box=box.DOUBLE_EDGE,
+        header_style="bold magenta",
+    )
+    report_data = []
+    required_pkgs = scoped_pkgs.get("required", [])
+    optional_pkgs = scoped_pkgs.get("optional", [])
+    excluded_pkgs = scoped_pkgs.get("excluded", [])
+    headers = ["Package", "Used?", "Risk Score", "Identified Risks"]
+    for h in headers:
+        justify = "left"
+        if h == "Risk Score":
+            justify = "right"
+        table.add_column(header=h, justify=justify)
+    for pkg, risk_obj in risk_results.items():
+        if not risk_obj:
+            continue
+        risk_metrics = risk_obj.get("risk_metrics")
+        scope = risk_obj.get("scope")
+        project_type_pkg = "{}:{}".format(project_type, pkg).lower()
+        if project_type_pkg in required_pkgs:
+            scope = "required"
+        elif project_type_pkg in optional_pkgs:
+            scope = "optional"
+        elif project_type_pkg in excluded_pkgs:
+            scope = "excluded"
+        package_usage = "N/A"
+        package_usage_simple = "N/A"
+        if scope == "required":
+            package_usage = "[bright_green][bold]Yes"
+            package_usage_simple = "Yes"
+        if scope == "optional":
+            package_usage = "[magenta]No"
+            package_usage_simple = "No"
+        if not risk_metrics:
+            continue
+        if risk_metrics.get("risk_score") and (
+            risk_metrics.get("risk_score") > config.pkg_max_risk_score
+            or risk_metrics.get("pkg_private_on_public_registry_risk")
+        ):
+            risk_score = f"""{round(risk_metrics.get("risk_score"), 2)}"""
+            data = [
+                pkg,
+                package_usage,
+                risk_score,
+            ]
+            edata = [
+                pkg,
+                package_usage_simple,
+                risk_score,
+            ]
+            risk_categories = []
+            risk_categories_simple = []
+            for rk, rv in risk_metrics.items():
+                if rk.endswith("_risk") and rv is True:
+                    rcat = rk.replace("_risk", "")
+                    help_text = config.risk_help_text.get(rcat)
+                    # Only add texts that are available.
+                    if help_text:
+                        if rcat in ("pkg_deprecated", "pkg_private_on_public_registry"):
+                            risk_categories.append(f":cross_mark: {help_text}")
+                        else:
+                            risk_categories.append(f":warning: {help_text}")
+                        risk_categories_simple.append(help_text)
+            data.append("\n".join(risk_categories))
+            edata.append(", ".join(risk_categories_simple))
+            table.add_row(*data)
+            report_data.append(dict(zip(headers, edata)))
+    if report_data:
+        console.print(table)
+        # Store the risk audit findings in jsonl format
+        if risk_report_file:
+            with open(risk_report_file, "w") as outfile:
+                for row in report_data:
+                    json.dump(row, outfile)
+                    outfile.write("\n")
+    else:
+        LOG.info("No package risks detected ✅")
+
+
 def analyse_licenses(project_type, licenses_results, license_report_file=None):
     if not licenses_results:
         return
@@ -225,10 +299,15 @@ def analyse_licenses(project_type, licenses_results, license_report_file=None):
                 data = [
                     *pkg_ver,
                     "{}{}".format(
-                        "[cyan]" if lic["spdx-id"].startswith("GPL") else "",
+                        "[cyan]"
+                        if "GPL" in lic["spdx-id"] or "CC-BY-" in lic["spdx-id"]
+                        else "",
                         lic["spdx-id"],
                     ),
-                    ", ".join(lic["conditions"]),
+                    ", ".join(lic["conditions"])
+                    .replace("--", " for ")
+                    .replace("-", " ")
+                    .title(),
                 ]
                 table.add_row(*data)
                 report_data.append(dict(zip(headers, data)))
