@@ -4,6 +4,7 @@ import pytest
 
 from depscan.lib.bom import get_pkg_list
 from depscan.lib.license import build_license_data, bulk_lookup
+from depscan.lib import analysis as analysis
 
 
 @pytest.fixture
@@ -84,3 +85,13 @@ def test_dual_license(test_license_data):
     pkg_list = get_pkg_list(test_bom)
     pkg_lic_dict = bulk_lookup(test_license_data, pkg_list)
     assert pkg_lic_dict
+
+
+def test_large_lookup(test_license_data):
+    test_bom = os.path.join(
+        os.path.dirname(os.path.realpath(__file__)), "data", "bom-docker.json"
+    )
+    pkg_list = get_pkg_list(test_bom)
+    pkg_lic_dict = bulk_lookup(test_license_data, pkg_list)
+    assert pkg_lic_dict
+    analysis.analyse_licenses("nodejs", pkg_lic_dict)
